==> Cluckshrooms-1.0.1-sources.jar: fun/wich/CluckshroomMod.java <==
package fun.wich;

import fun.wich.mixin.LootTablesMixin;
import net.fabricmc.api.ModInitializer;

import net.fabricmc.fabric.api.biome.v1.BiomeModifications;
import net.fabricmc.fabric.api.biome.v1.BiomeSelectors;
import net.fabricmc.fabric.api.itemgroup.v1.ItemGroupEvents;
import net.fabricmc.fabric.api.object.builder.v1.entity.FabricDefaultAttributeRegistry;
import net.minecraft.class_1297;
import net.minecraft.class_1299;
import net.minecraft.class_1311;
import net.minecraft.class_1317;
import net.minecraft.class_1792;
import net.minecraft.class_1826;
import net.minecraft.class_1972;
import net.minecraft.class_2248;
import net.minecraft.class_2315;
import net.minecraft.class_2378;
import net.minecraft.class_243;
import net.minecraft.class_2902;
import net.minecraft.class_2960;
import net.minecraft.class_3414;
import net.minecraft.class_52;
import net.minecraft.class_5321;
import net.minecraft.class_6862;
import net.minecraft.class_7706;
import net.minecraft.class_7923;
import net.minecraft.class_7924;
import net.minecraft.class_9169;
import net.minecraft.entity.*;
import java.util.function.Function;

public class CluckshroomMod implements ModInitializer {
	public static final String MOD_ID = "wich";

	public static final class_3414 ENTITY_CLUCKSHROOM_AMBIENT = register("entity.cluckshroom.ambient");
	public static final class_3414 ENTITY_CLUCKSHROOM_DEATH = register("entity.cluckshroom.death");
	public static final class_3414 ENTITY_CLUCKSHROOM_EGG = register("entity.cluckshroom.egg");
	public static final class_3414 ENTITY_CLUCKSHROOM_MUSHROOM = register("entity.cluckshroom.mushroom");
	public static final class_3414 ENTITY_CLUCKSHROOM_HURT = register("entity.cluckshroom.hurt");
	public static final class_3414 ENTITY_CLUCKSHROOM_STEP = register("entity.cluckshroom.step");
	public static final class_3414 ENTITY_CLUCKSHROOM_CONVERT = register("entity.cluckshroom.convert");
	public static final class_3414 ENTITY_CLUCKSHROOM_SHEAR = register("entity.cluckshroom.shear");
	private static class_3414 register(String path) {
		class_2960 id = class_2960.method_60655(MOD_ID, path);
		return class_2378.method_10230(class_7923.field_41172, id, class_3414.method_47908(id));
	}

	public static final class_5321<class_52> CLUCKSHROOM_LAY_GAMEPLAY = registerLootTable("gameplay/cluckshroom_lay");
	public static final class_5321<class_52> CLUCKSHROOM_SHEARING = registerLootTable("shearing/cluckshroom");
	private static class_5321<class_52> registerLootTable(String name) {
		return LootTablesMixin.registerLootTable(class_5321.method_29179(class_7924.field_50079, class_2960.method_60655(MOD_ID, name)));
	}

	public static final class_6862<class_1792> TAG_CLUCKSHROOM_FOOD = class_6862.method_40092(class_7924.field_41197, class_2960.method_60655(MOD_ID, "cluckshroom_food"));
	public static final class_6862<class_2248> TAG_CLUCKSHROOMS_SPAWNABLE_ON = class_6862.method_40092(class_7924.field_41254, class_2960.method_60655(MOD_ID, "cluckshrooms_spawnable_on"));

	public static final class_1299<CluckshroomEntity> CLUCKSHROOM = register(
			"cluckshroom",
			class_1299.class_1300.method_5903(CluckshroomEntity::new, class_1311.field_6302)
					.method_17687(0.4F, 0.7F)
					.method_55687(0.644F)
					.method_55690(new class_243(0.0F, 0.7, -0.1))
					.method_27299(10)
	);
	public static final class_1299<CluckshroomEggEntity> CLUCKSHROOM_EGG = register(
			"cluckshroom_egg",
			class_1299.class_1300.<CluckshroomEggEntity>method_5903(CluckshroomEggEntity::new, class_1311.field_17715)
					.method_63006()
					.method_17687(0.25F, 0.25F)
					.method_27299(4)
					.method_27300(10)
	);
	private static <T extends class_1297> class_1299<T> register(String name, class_1299.class_1300<T> type) {
		class_5321<class_1299<?>> key = class_5321.method_29179(class_7924.field_41266, class_2960.method_60655(MOD_ID, name));
		class_1299<T> entityType = type.method_5905(key);
		class_2378.method_39197(class_7923.field_41177, key, entityType);
		return entityType;
	}
	public static final class_1792 RED_CLUCKSHROOM_EGG = register("red_cluckshroom_egg", CluckshroomEggItem::new, new class_1792.class_1793().method_7889(16));
	public static final class_1792 BROWN_CLUCKSHROOM_EGG = register("brown_cluckshroom_egg", CluckshroomEggItem::new, new class_1792.class_1793().method_7889(16));
	public static final class_1792 CLUCKSHROOM_SPAWN_EGG = register("cluckshroom_spawn_egg", class_1826::new, new class_1792.class_1793().method_72499(CLUCKSHROOM));
	public static class_1792 register(String name, Function<class_1792.class_1793, class_1792> itemFactory, class_1792.class_1793 settings) {
		class_5321<class_1792> key = class_5321.method_29179(class_7924.field_41197, class_2960.method_60655(MOD_ID, name));
		class_1792 item = itemFactory.apply(settings.method_63686(key));
		class_2378.method_39197(class_7923.field_41178, key, item);
		return item;
	}

	@Override
	public void onInitialize() {
		//Attributes
		FabricDefaultAttributeRegistry.register(CLUCKSHROOM, CluckshroomEntity.createCluckshroomAttributes());
		//Spawning
		class_1317.method_20637(CLUCKSHROOM, class_9169.field_48745, class_2902.class_2903.field_13203, CluckshroomEntity::canSpawn);
		BiomeModifications.addSpawn(BiomeSelectors.includeByKey(class_1972.field_9462),
				class_1311.field_6294, CLUCKSHROOM, 6, 2, 6);
		//Items
		ItemGroupEvents.modifyEntriesEvent(class_7706.field_40205).register(itemGroup -> itemGroup.method_45421(CLUCKSHROOM_SPAWN_EGG));
		//Eggs
		ItemGroupEvents.modifyEntriesEvent(class_7706.field_40202).register(itemGroup -> {
			itemGroup.method_45421(RED_CLUCKSHROOM_EGG);
			itemGroup.method_45421(BROWN_CLUCKSHROOM_EGG);
		});
		ItemGroupEvents.modifyEntriesEvent(class_7706.field_41062).register(itemGroup -> {
			itemGroup.method_45421(RED_CLUCKSHROOM_EGG);
			itemGroup.method_45421(BROWN_CLUCKSHROOM_EGG);
		});
		class_2315.method_58681(RED_CLUCKSHROOM_EGG);
		class_2315.method_58681(BROWN_CLUCKSHROOM_EGG);
	}
}

==> Cluckshrooms-1.0.2-sources.jar: fun/wich/CluckshroomMod.java <==
package fun.wich;

import fun.wich.mixin.Cluckshrooms_LootTablesMixin;
import net.fabricmc.api.ModInitializer;

import net.fabricmc.fabric.api.biome.v1.BiomeModifications;
import net.fabricmc.fabric.api.biome.v1.BiomeSelectors;
import net.fabricmc.fabric.api.itemgroup.v1.ItemGroupEvents;
import net.fabricmc.fabric.api.object.builder.v1.entity.FabricDefaultAttributeRegistry;
import net.minecraft.class_1297;
import net.minecraft.class_1299;
import net.minecraft.class_1311;
import net.minecraft.class_1317;
import net.minecraft.class_1792;
import net.minecraft.class_1826;
import net.minecraft.class_1972;
import net.minecraft.class_2248;
import net.minecraft.class_2315;
import net.minecraft.class_2378;
import net.minecraft.class_243;
import net.minecraft.class_2902;
import net.minecraft.class_2960;
import net.minecraft.class_3414;
import net.minecraft.class_52;
import net.minecraft.class_5321;
import net.minecraft.class_6862;
import net.minecraft.class_7706;
import net.minecraft.class_7923;
import net.minecraft.class_7924;
import net.minecraft.class_9169;
import net.minecraft.entity.*;
import java.util.function.Function;

public class CluckshroomMod implements ModInitializer {
	public static final String MOD_ID = "wich";

	public static final class_3414 ENTITY_CLUCKSHROOM_AMBIENT = register("entity.cluckshroom.ambient");
	public static final class_3414 ENTITY_CLUCKSHROOM_DEATH = register("entity.cluckshroom.death");
	public static final class_3414 ENTITY_CLUCKSHROOM_EGG = register("entity.cluckshroom.egg");
	public static final class_3414 ENTITY_CLUCKSHROOM_MUSHROOM = register("entity.cluckshroom.mushroom");
	public static final class_3414 ENTITY_CLUCKSHROOM_HURT = register("entity.cluckshroom.hurt");
	public static final class_3414 ENTITY_CLUCKSHROOM_STEP = register("entity.cluckshroom.step");
	public static final class_3414 ENTITY_CLUCKSHROOM_CONVERT = register("entity.cluckshroom.convert");
	public static final class_3414 ENTITY_CLUCKSHROOM_SHEAR = register("entity.cluckshroom.shear");
	private static class_3414 register(String path) {
		class_2960 id = class_2960.method_60655(MOD_ID, path);
		return class_2378.method_10230(class_7923.field_41172, id, class_3414.method_47908(id));
	}

	public static final class_5321<class_52> CLUCKSHROOM_LAY_GAMEPLAY = registerLootTable("gameplay/cluckshroom_lay");
	public static final class_5321<class_52> CLUCKSHROOM_SHEARING = registerLootTable("shearing/cluckshroom");
	private static class_5321<class_52> registerLootTable(String name) {
		return Cluckshrooms_LootTablesMixin.registerLootTable(class_5321.method_29179(class_7924.field_50079, class_2960.method_60655(MOD_ID, name)));
	}

	public static final class_6862<class_1792> TAG_CLUCKSHROOM_FOOD = class_6862.method_40092(class_7924.field_41197, class_2960.method_60655(MOD_ID, "cluckshroom_food"));
	public static final class_6862<class_2248> TAG_CLUCKSHROOMS_SPAWNABLE_ON = class_6862.method_40092(class_7924.field_41254, class_2960.method_60655(MOD_ID, "cluckshrooms_spawnable_on"));

	public static final class_1299<CluckshroomEntity> CLUCKSHROOM = register(
			"cluckshroom",
			class_1299.class_1300.method_5903(CluckshroomEntity::new, class_1311.field_6302)
					.method_17687(0.4F, 0.7F)
					.method_55687(0.644F)
					.method_55690(new class_243(0.0F, 0.7, -0.1))
					.method_27299(10)
	);
	public static final class_1299<CluckshroomEggEntity> CLUCKSHROOM_EGG = register(
			"cluckshroom_egg",
			class_1299.class_1300.<CluckshroomEggEntity>method_5903(CluckshroomEggEntity::new, class_1311.field_17715)
					.method_63006()
					.method_17687(0.25F, 0.25F)
					.method_27299(4)
					.method_27300(10)
	);
	private static <T extends class_1297> class_1299<T> register(String name, class_1299.class_1300<T> type) {
		class_5321<class_1299<?>> key = class_5321.method_29179(class_7924.field_41266, class_2960.method_60655(MOD_ID, name));
		class_1299<T> entityType = type.method_5905(key);
		class_2378.method_39197(class_7923.field_41177, key, entityType);
		return entityType;
	}
	public static final class_1792 RED_CLUCKSHROOM_EGG = register("red_cluckshroom_egg", CluckshroomEggItem::new, new class_1792.class_1793().method_7889(16));
	public static final class_1792 BROWN_CLUCKSHROOM_EGG = register("brown_cluckshroom_egg", CluckshroomEggItem::new, new class_1792.class_1793().method_7889(16));
	public static final class_1792 CLUCKSHROOM_SPAWN_EGG = register("cluckshroom_spawn_egg", class_1826::new, new class_1792.class_1793().method_72499(CLUCKSHROOM));
	public static class_1792 register(String name, Function<class_1792.class_1793, class_1792> itemFactory, class_1792.class_1793 settings) {
		class_5321<class_1792> key = class_5321.method_29179(class_7924.field_41197, class_2960.method_60655(MOD_ID, name));
		class_1792 item = itemFactory.apply(settings.method_63686(key));
		class_2378.method_39197(class_7923.field_41178, key, item);
		return item;
	}

	@Override
	public void onInitialize() {
		//Attributes
		FabricDefaultAttributeRegistry.register(CLUCKSHROOM, CluckshroomEntity.createCluckshroomAttributes());
		//Spawning
		class_1317.method_20637(CLUCKSHROOM, class_9169.field_48745, class_2902.class_2903.field_13203, CluckshroomEntity::canSpawn);
		BiomeModifications.addSpawn(BiomeSelectors.includeByKey(class_1972.field_9462),
				class_1311.field_6294, CLUCKSHROOM, 6, 2, 6);
		//Items
		ItemGroupEvents.modifyEntriesEvent(class_7706.field_40205).register(itemGroup -> itemGroup.method_45421(CLUCKSHROOM_SPAWN_EGG));
		//Eggs
		ItemGroupEvents.modifyEntriesEvent(class_7706.field_40202).register(itemGroup -> {
			itemGroup.method_45421(RED_CLUCKSHROOM_EGG);
			itemGroup.method_45421(BROWN_CLUCKSHROOM_EGG);
		});
		ItemGroupEvents.modifyEntriesEvent(class_7706.field_41062).register(itemGroup -> {
			itemGroup.method_45421(RED_CLUCKSHROOM_EGG);
			itemGroup.method_45421(BROWN_CLUCKSHROOM_EGG);
		});
		class_2315.method_58681(RED_CLUCKSHROOM_EGG);
		class_2315.method_58681(BROWN_CLUCKSHROOM_EGG);
	}
}
